Class: Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1SendTestMessageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/essentialcontacts_v1/classes.rb,
lib/google/apis/essentialcontacts_v1/representations.rb,
lib/google/apis/essentialcontacts_v1/representations.rb

Overview

Request message for the SendTestMessage method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudEssentialcontactsV1SendTestMessageRequest

Returns a new instance of GoogleCloudEssentialcontactsV1SendTestMessageRequest.



159
160
161
# File 'lib/google/apis/essentialcontacts_v1/classes.rb', line 159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contactsArray<String>

Required. The list of names of the contacts to send a test message to. Format: organizations/organization/contacts/contact, folders/folder/contacts/ contact or projects/project/contacts/contact (where project is the project number) Corresponds to the JSON property contacts

Returns:

  • (Array<String>)


151
152
153
# File 'lib/google/apis/essentialcontacts_v1/classes.rb', line 151

def contacts
  @contacts
end

#notification_categoryString

Required. The notification category to send the test message for. All contacts must be subscribed to this category. Corresponds to the JSON property notificationCategory

Returns:

  • (String)


157
158
159
# File 'lib/google/apis/essentialcontacts_v1/classes.rb', line 157

def notification_category
  @notification_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



164
165
166
167
# File 'lib/google/apis/essentialcontacts_v1/classes.rb', line 164

def update!(**args)
  @contacts = args[:contacts] if args.key?(:contacts)
  @notification_category = args[:notification_category] if args.key?(:notification_category)
end