Class: Google::Apis::EssentialcontactsV1::EssentialcontactsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::EssentialcontactsV1::EssentialcontactsService
- Defined in:
- lib/google/apis/essentialcontacts_v1/service.rb
Overview
Essential Contacts API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://essentialcontacts.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#compute_folder_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse
Lists all contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
-
#compute_organization_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse
Lists all contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
-
#compute_project_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse
Lists all contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
-
#create_folder_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Adds a new contact for a resource.
-
#create_organization_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Adds a new contact for a resource.
-
#create_project_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Adds a new contact for a resource.
-
#delete_folder_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Deletes a contact.
-
#delete_organization_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Deletes a contact.
-
#delete_project_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Deletes a contact.
-
#get_folder_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Gets a single contact.
-
#get_organization_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Gets a single contact.
-
#get_project_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Gets a single contact.
-
#initialize ⇒ EssentialcontactsService
constructor
A new instance of EssentialcontactsService.
-
#list_folder_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse
Lists the contacts that have been set on a resource.
-
#list_organization_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse
Lists the contacts that have been set on a resource.
-
#list_project_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse
Lists the contacts that have been set on a resource.
-
#patch_folder_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Updates a contact.
-
#patch_organization_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Updates a contact.
-
#patch_project_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Updates a contact.
-
#send_folder_contact_test_message(resource, google_cloud_essentialcontacts_v1_send_test_message_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Allows a contact admin to send a test message to contact to verify that it has been configured correctly.
-
#send_organization_contact_test_message(resource, google_cloud_essentialcontacts_v1_send_test_message_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Allows a contact admin to send a test message to contact to verify that it has been configured correctly.
-
#send_project_contact_test_message(resource, google_cloud_essentialcontacts_v1_send_test_message_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Allows a contact admin to send a test message to contact to verify that it has been configured correctly.
Constructor Details
#initialize ⇒ EssentialcontactsService
Returns a new instance of EssentialcontactsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-essentialcontacts_v1', client_version: Google::Apis::EssentialcontactsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#compute_folder_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse
Lists all contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 91 def compute_folder_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/contacts:compute', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse command.params['parent'] = parent unless parent.nil? command.query['notificationCategories'] = notification_categories unless notification_categories.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#compute_organization_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse
Lists all contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 359 def compute_organization_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/contacts:compute', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse command.params['parent'] = parent unless parent.nil? command.query['notificationCategories'] = notification_categories unless notification_categories.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#compute_project_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse
Lists all contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 627 def compute_project_contact(parent, notification_categories: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/contacts:compute', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ComputeContactsResponse command.params['parent'] = parent unless parent.nil? command.query['notificationCategories'] = notification_categories unless notification_categories.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_folder_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Adds a new contact for a resource.
127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 127 def create_folder_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/contacts', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.request_object = google_cloud_essentialcontacts_v1_contact_object command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Adds a new contact for a resource.
395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 395 def create_organization_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/contacts', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.request_object = google_cloud_essentialcontacts_v1_contact_object command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Adds a new contact for a resource.
663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 663 def create_project_contact(parent, google_cloud_essentialcontacts_v1_contact_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/contacts', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.request_object = google_cloud_essentialcontacts_v1_contact_object command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_folder_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Deletes a contact.
161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 161 def delete_folder_contact(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Deletes a contact.
429 430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 429 def delete_organization_contact(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Deletes a contact.
697 698 699 700 701 702 703 704 705 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 697 def delete_project_contact(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Gets a single contact.
193 194 195 196 197 198 199 200 201 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 193 def get_folder_contact(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Gets a single contact.
461 462 463 464 465 466 467 468 469 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 461 def get_organization_contact(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_contact(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Gets a single contact.
729 730 731 732 733 734 735 736 737 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 729 def get_project_contact(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse
Lists the contacts that have been set on a resource.
234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 234 def list_folder_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/contacts', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse
Lists the contacts that have been set on a resource.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 502 def list_organization_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/contacts', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse
Lists the contacts that have been set on a resource.
770 771 772 773 774 775 776 777 778 779 780 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 770 def list_project_contacts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/contacts', ) command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1ListContactsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_folder_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Updates a contact. Note: A contact's email address cannot be changed.
272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 272 def patch_folder_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.request_object = google_cloud_essentialcontacts_v1_contact_object command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Updates a contact. Note: A contact's email address cannot be changed.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 540 def patch_organization_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.request_object = google_cloud_essentialcontacts_v1_contact_object command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact
Updates a contact. Note: A contact's email address cannot be changed.
808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 808 def patch_project_contact(name, google_cloud_essentialcontacts_v1_contact_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.request_object = google_cloud_essentialcontacts_v1_contact_object command.response_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1Contact command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#send_folder_contact_test_message(resource, google_cloud_essentialcontacts_v1_send_test_message_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Allows a contact admin to send a test message to contact to verify that it has been configured correctly.
310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 310 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}/contacts:sendTestMessage', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1SendTestMessageRequest::Representation command.request_object = command.response_representation = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#send_organization_contact_test_message(resource, google_cloud_essentialcontacts_v1_send_test_message_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Allows a contact admin to send a test message to contact to verify that it has been configured correctly.
578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 578 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}/contacts:sendTestMessage', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1SendTestMessageRequest::Representation command.request_object = command.response_representation = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#send_project_contact_test_message(resource, google_cloud_essentialcontacts_v1_send_test_message_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty
Allows a contact admin to send a test message to contact to verify that it has been configured correctly.
846 847 848 849 850 851 852 853 854 855 856 |
# File 'lib/google/apis/essentialcontacts_v1/service.rb', line 846 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}/contacts:sendTestMessage', ) command.request_representation = Google::Apis::EssentialcontactsV1::GoogleCloudEssentialcontactsV1SendTestMessageRequest::Representation command.request_object = command.response_representation = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::EssentialcontactsV1::GoogleProtobufEmpty command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |